@@ -14,10 +14,11 @@
 #include <qtimer.h>
 #include <qpopmenu.h>
 #include <qpoint.h>
+#include <ksystemtray.h>
 #include "kderadio.h"
 
 
-class DockWidget : public QWidget {
+class DockWidget : public KSystemTray {
 
   Q_OBJECT
 
@@ -39,18 +40,23 @@ public slots:
     void paintIcon();
     void slotIncreaseStation(void);
     void slotDecreaseStation(void);
-
+	void slotDoNothing(void);
 public:
     const bool isDocked();
     const bool isToggled();
     void SaveKDERadioPosition();
-
+	void setCaptions(KRadio *);
 private:
   class KRadio *pkderadio;
   bool docked;
   int toggleID;
   int pos_x;
   int pos_y;
+  
+  int nextID;
+  int prevID;
+  int currID;
+
   QPopupMenu *popup_m;
   bool HaveKDERadioPosition;
   QPixmap miniKDERadioPixmap;
