@@ -20,6 +20,7 @@
 #endif
 #include <errno.h>
 #include <assert.h>   // Wollen wir auf jeden Fall :-)
+#include <stdlib.h>	  // We need it for strtod
 
 // Qt Zeug
 #include <qstring.h>
@@ -31,12 +32,18 @@
 #include <qgroupbox.h>
 #include <qtooltip.h>
 #include <qstrlist.h>
+#include <qtextstream.h>
+#include <qlineedit.h>
 
 // KDE Includes
-#include <kfm.h>
+// #include <kfm.h>
 #include <kapp.h>
+#include <kmainwindow.h>
+#include <kmenubar.h>
 #include <kaccel.h>
 #include <kfiledialog.h>
+#include <klocale.h>
+#include <kiconloader.h>
 
 // Eigenes
 #include "radioctrl.h"
@@ -67,9 +74,14 @@ KRadio::KRadio() {
 	// Die Keyboard Bindings definieren
 	// und den Accelarator zurckgeben, womit nachher 
 	// die Popup Mens definiert werden
-	KAccel * keyaccl = initKeyAccel();
+	KAccel * keyaccel = new KAccel(this);
+
+	// Define the keybindings
+	initKeyAccel(keyaccel);
+
 	// Die Popup Mens 
-	initPopupMenus(keyaccl);
+	initPopupMenus(keyaccel);
+
 	// Signale und Slots verbinden
 	initConnect();
 	// Die Stationsliste laden, bzw. wenn sie nicht vorhanden 
@@ -87,9 +99,10 @@ KRadio::KRadio() {
 	// Nun noch diverse Konfigurationsarbeit erledigen
 	// Eine Drag'n Drop Zone einrichten. Das Main Widget 
         // nimmt all unsere Drag's auf.
-	connect( new KDNDDropZone( this , DndURL), \
-		SIGNAL( dropAction( KDNDDropZone *) ), \
-		SLOT( slotDropEvent( KDNDDropZone *) ) );
+	// KEINE KDE drop zone
+	//	connect( new KDNDDropZone( this , DndURL), 
+	//		SIGNAL( dropAction( KDNDDropZone *) ), 
+	//		SLOT( slotDropEvent( KDNDDropZone *) ) );
 
 
 	// Am Schlu des Konstruktors noch das Radio auf
@@ -100,9 +113,9 @@ KRadio::KRadio() {
 		QString a;
 		a = sys_errlist[-(pRadio->getStatus())];
 
-		QMessageBox::critical(0, "kderadio", QString(i18n("Error while "\
-		"opening "))+ Device + QString(": \n") + \
-		a + QString("\n") );
+		QMessageBox::critical(0, "kderadio",  
+		i18n("Error while opening ") + Device + QString(": \n") + \
+		a + QString("\n"));
 //		exit(1);
 	}
 	// Caption und Comboxbox setzen (Frequenz ist schon 
@@ -133,44 +146,50 @@ void KRadio::initWidgets(void) {
 }
 
 // Die Keybindings mit der Methode von KDE 1.1 definieren.
-KAccel * KRadio::initKeyAccel(void) {
-	KAccel * keyaccl = new KAccel( this );
-	keyaccl->connectItem(KAccel::Save, this, SLOT( slotSaveFile() ) ); 
-	keyaccl->connectItem(KAccel::Open, this, SLOT( slotOpenFile() ) );
-	keyaccl->connectItem(KAccel::Quit, kapp, SLOT( quit() ) );
-	return keyaccl;
+KAccel * KRadio::initKeyAccel(KAccel * keyaccel) {
+//	keyaccel->connectItem("save", this, SLOT( slotSaveFile() ) ); 
+//	keyaccel->connectItem("&Open", this, SLOT( slotOpenFile() ) );
+//	keyaccel->connectItem("quit", kapp, SLOT( quit() ) );
+	return keyaccel;
 }
 
 // Die Popup-Mens belegen
 void KRadio::initPopupMenus(KAccel * keyaccl) {
 	// Das "File" Popupmenu
-	int id = pFileMenu->insertItem(i18n("&Open"), this, SLOT( slotOpenFile() ));
-	keyaccl->changeMenuAccel(pFileMenu, id, KAccel::Open);
-	id = pFileMenu->insertItem(i18n("&Save"), this, SLOT( slotSaveFile() ));
-	keyaccl->changeMenuAccel(pFileMenu, id, KAccel::Save);
-	
+	int id = pFileMenu->insertItem(i18n("Open"), this, SLOT( slotOpenFile() ));
+	pFileMenu->changeItem(id, SmallIcon("fileopen"), i18n("Open"));
+//	keyaccl->insertItem("&Open", "&Open", 0, id, pFileMenu);
+	id = pFileMenu->insertItem(i18n("Save"), this, SLOT( slotSaveFile() ));
+	pFileMenu->changeItem(id, SmallIcon("filesave"), i18n("Save"));
+//	keyaccl->changeMenuAccel(pFileMenu, id, "save");
 	pFileMenu->insertSeparator();
-	id = pFileMenu->insertItem(i18n("&Quit"), this, SLOT( slotQuit() ) ); 
-	keyaccl->changeMenuAccel(pFileMenu, id, KAccel::Quit);
+	id = pFileMenu->insertItem(i18n("Quit"), this, SLOT( slotQuit() ) ); 
+	 pFileMenu->changeItem(id, SmallIcon("exit"), i18n("Quit"));
+//	keyaccl->changeMenuAccel(pFileMenu, id, "quit");
 	
 	// Das File Popupmenue in die Menuleiste eintragen.
 	menuBar()->insertItem(i18n("&File"), pFileMenu);
 
 	// Das Optionen Menu 
-	id = pExtraMenu->insertItem(i18n("&Dock"), this, \
+	id = pExtraMenu->insertItem(i18n("Dock"), this, \
 		SLOT( slotDock()) );
-	id = pExtraMenu->insertItem(i18n("&Radiodevice"), this, \
+	pExtraMenu->changeItem(id, SmallIcon("attach"), i18n("Dock"));
+
+	id = pExtraMenu->insertItem(i18n("Radiodevice"), this, \
 		SLOT( slotPreferencesMenu()));
+	pExtraMenu->changeItem(id, SmallIcon("configure"), i18n("Radiodevice"));
+
 	menuBar()->insertItem(i18n("&Options"), pExtraMenu);
 
 	// Und der Abstand zur Hilfe
 	menuBar()->insertSeparator();
 	// Wir lassen uns das Hilfe Menue mit Hilfe von KDE erzeugen.
-	pHelpMenu = kapp->getHelpMenu(true, 
+	pHelpMenu = this->helpMenu(
 		i18n("kderadio, a KDE application for\n"
                 "controlling a video4linux compatible\n"
-                "radio card.\n\n(C) 1998 by Carsten Gross\n"
-                "carsten@sol.wohnheim.uni-ulm.de\n"\
+                "radio card.\n\n(C) 1998,2001 by Carsten Gross\n"
+                "carsten@siski.de\n"\
+		"http://www.siski.de/~carsten\n"\
 		"Copying licence is GPL\n"));
 	menuBar()->insertItem(i18n("&Help"), pHelpMenu );
 	return;
@@ -226,8 +245,8 @@ void KRadio::initConnect(void) {
 	connect ( pFrequenzBox, SIGNAL( valueChanged(int ) ), this, 
 		SLOT( slotChangeFrequenz(int )));
 	// Signal "Neue Station" (Combobox verndert) auf Funktion
-	connect ( pStationList, SIGNAL( activated(const char *) ), this,
-		SLOT( slotChangeStation(const char *)));
+	connect ( pStationList, SIGNAL( activated(const QString &) ), this,
+		SLOT( slotChangeStation(const QString &)));
 	return;
 }
 
@@ -239,7 +258,8 @@ double KRadio::initList(void) {
 	pListe->setAutoDelete(TRUE);
 	
 	// Globales Config File einlesen (Stationsliste)
-	readProperties(kapp->getConfig());
+	kapp->disableSessionManagement();
+	readGlobalProperties(kapp->config());
 
 	// In pListe sind die ganzen Programme drin.
 	// Falls das Object leer ist, dann legen wir ein einziges Programm 
@@ -274,7 +294,7 @@ void KRadio::initTooltips(void) {
 }
 
 
-// Die Dateio "FileName" laden.
+// Die Datei "FileName" laden.
 void KRadio::loadFile(QString FileName) {
 	RadioProgramm * p;	
 
@@ -322,6 +342,9 @@ void KRadio::loadFile(QString FileName) {
 void KRadio::slotOpenFile() {
 
 	QString FileName(KFileDialog::getOpenFileName(0, "*.freq", 0, 0));
+	if (FileName.isNull()) {
+		return;
+	}
 	loadFile(FileName);
 	return;
 }
@@ -354,10 +377,15 @@ void KRadio::slotSaveFile() {
 
 // Programm verlassen
 void KRadio::slotQuit() {
-	saveProperties(kapp->getConfig());
+
+	pRadio->off();
+	saveGlobalProperties(kapp->config());
 	kapp->quit();
 }
 
+// No drag and drop zones any more
+
+#if 0 
 void KRadio::slotDropEvent( KDNDDropZone * DNDevent) {
 	
 	assert(DNDevent);
@@ -379,7 +407,7 @@ void KRadio::slotDropEvent( KDNDDropZone * DNDevent) {
 		}
 	}
 }
-
+#endif 
 
 // Stelle die genderte Frequenz auch am Tuner ein.
 void KRadio::slotChangeFrequenz(int freq) {
@@ -394,9 +422,6 @@ void KRadio::slotChangeFrequenz(int freq) {
 	RadioProgramm * p;		// Zum Durchsuchen der Liste
 	signed int i = 0;		// Pointer auf die Position	
 
-#ifndef NDEBUG
-	cerr << "Frequenz: " << freq << "\n";
-#endif
 	assert((frequenz >= 87.5) && (frequenz <=108.0));
 
 	// Gibt es vielleicht einen Stationsnamen in der Liste?
@@ -420,12 +445,13 @@ void KRadio::slotChangeFrequenz(int freq) {
 		a = a + " MHz";	
 		this->setCaption(a);
 	}
+	pDocking->setCaptions(this);
 	pRadio->setFrequenz(frequenz);  // Frequenz am Tuner einstellen
 	return;
 }
 
 // Eine Read Only ComboBox.. ist einfacher... 
-void KRadio::slotChangeStation(const char *Station) {
+void KRadio::slotChangeStation(const QString& Station) {
 	RadioProgramm * p;
 	bool flag=FALSE;
 	int index = 0;
@@ -498,6 +524,56 @@ void KRadio::slotNewStation(void) {
 	return;
 }
 
+// get currently tuned in station
+
+QString KRadio::getStation() {
+	int index;
+	RadioProgramm *p;
+
+	index = pListe->at();
+	if (index != -1) {
+		p = pListe->at(index);
+		return (p->Station());
+	} 
+	return NULL;
+}	
+		
+// get next station 
+
+QString KRadio::nextStation() {
+	int index;
+	int oldindex;
+	RadioProgramm *p;
+
+	index = pListe->at();	
+	oldindex = index;
+	index++;
+	p = pListe->at(index);
+	pListe->at(oldindex);
+	if (p != NULL) {
+		return p->Station();
+	}
+	return NULL;	
+}		
+
+// get previous station
+
+QString KRadio::prevStation() {
+	int index;
+	int oldindex;	
+	RadioProgramm *p;
+
+	index = pListe->at();
+	oldindex = index;
+	index--;
+	p = pListe->at(index);
+	pListe->at(oldindex);
+	if ( p != NULL) {
+		return p->Station();
+	} 
+	return NULL;
+}
+
 // Eine Station an der aktuellen Listenposition entfernen
 
 void KRadio::slotRemoveStation(void) {
@@ -515,11 +591,11 @@ void KRadio::slotRemoveStation(void) {
 	return;
 }	
 
-// saveProperties wird aufgerufen wenn die Applikation "about to close" ist
+// saveGlobalProperties wird aufgerufen wenn die Applikation "about to close" ist
 // Das heit zum Beispiel wenn der Benutzer den "Ausloggen" beim kwm
 // gewhlt hat. Wir speichern unsere aktuelle Frequenzliste und was man
 // sonst so configurieren kann.
-void KRadio::saveProperties(KConfig * config) {
+void KRadio::saveGlobalProperties(KConfig * config) {
 	RadioProgramm *p;
 
 	QStrList a;
@@ -546,7 +622,7 @@ void KRadio::saveProperties(KConfig * config) {
 }
 
 // Die Frequenzliste wieder laden
-void KRadio::readProperties(KConfig * config) {
+void KRadio::readGlobalProperties(KConfig * config) {
 	RadioProgramm *p;
 
 	QString device;
