@@ -17,8 +17,8 @@
 #include <qdialog.h>
 #include <qgroupbox.h>
 #include <qpushbutton.h>
-#include "radioctrl.h"
 #include "kderadio.h"
+#include "radioctrl.h"
 
 class StationsDialog : public QDialog {
 	Q_OBJECT
@@ -27,7 +27,7 @@ class StationsDialog : public QDialog {
 		char * getStation();
 	public slots:
 		void accept(void);
-		void slotChangeText(const char *);
+		void slotChangeText(const QString &);
 	protected:
 	        QPushButton     * pOk, * pCancel;
 	        QLabel          * pFrequenzAnzeige;
